@@ -77,7 +77,7 @@ def validate_lims_upload(
     lims_id: str,
     table_name: str = "dev",
 ):
-    results = get_validation_results(client, lims_id, table_name)
+    results = get_validation_results(client, lims_id, None, table_name)
     validated = validate_lims(
         cursor,
         lims_id,
