@@ -16,8 +16,13 @@ def put_validation_manifest(table, manifest: ValidationManifest):
     return table.insert_one(from_ValidationManifest(manifest))
 
 
-def get_asset_validation_results(table, lims_id: str) -> AssetValidationResult:
-    data = table.find({"lims_id": lims_id}, {"_id": False})
+def get_asset_validation_results(
+    table, lims_id: str, asset_type: str = None
+) -> AssetValidationResult:
+    query = {"lims_id": lims_id}
+    if asset_type is not None:
+        query["manifest.asset_type"] = asset_type
+    data = table.find(query, {"_id": False})
     return [to_AssetValidationResult(doc) for doc in data]
 
 
